using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using AmazonWrapper.Amazon.ECSWebservice;

public partial class Default2 : System.Web.UI.Page
{
	private string subscriptionId = ConfigurationManager.AppSettings["Amazon.Webservice.SubscriptionId"].ToString();
	private string associateId = ConfigurationManager.AppSettings["Amazon.Associates.ID"].ToString();
	private string asin;

	protected void Page_Load(object sender, EventArgs e)
	{
		try
		{
			asin = Request.QueryString["asin"];
			GetItemDetails(asin);
		}
		catch
		{
			lblErrMsg.Text = "An error ocurred while processing your request. Please try again later.";
		}
	}

	private void GetItemDetails(string asin)
	{
		string _rating;
		string _imagePath;
		string _imageURL;
		double _listPrice;
		double _salesPrice;
		double _savings;
		ItemDetailsRequest req = new ItemDetailsRequest();
		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;

		Item item = req.GetItemDetails(asin, true);

		if (item != null)
		{

			if (item.ItemAttributes.Title != null)
			{
				titleLabel.Text = item.ItemAttributes.Title;
				lblReviewTitle.Text = item.ItemAttributes.Title;
				Page.Title = "DNK Amazon Store :: " + item.ItemAttributes.Title; 
			}

			if (item.ItemAttributes.ListPrice != null)
			{
				lblListPrice.Text = item.ItemAttributes.ListPrice.FormattedPrice;
			}

			if (item.ItemAttributes.Studio != null)
			{
				studioLabel.Text = item.ItemAttributes.Studio;
			}

			if (item.CustomerReviews != null)
			{
				 _rating = item.CustomerReviews.AverageRating.ToString();
				 _imagePath = "images/stars/stars-" + item.CustomerReviews.AverageRating.ToString().Replace(".", "-") + ".gif";
				
				if (_rating.Trim().Length > 1)
				{
					_imagePath = "images/stars/stars-" + item.CustomerReviews.AverageRating.ToString().Replace(".", "-") + ".gif";
				}
				else
				{
					_imagePath = "images/stars/stars-" + item.CustomerReviews.AverageRating.ToString() + "-0.gif";
				}

				imgRating.ImageUrl = _imagePath;
				imgRating.ToolTip = item.CustomerReviews.AverageRating.ToString() + " /5";

				DataTable reviews = new DataTable();
				reviews.Columns.Add(new DataColumn("Summary", typeof(string)));
				reviews.Columns.Add(new DataColumn("Rating", typeof(string)));
				reviews.Columns.Add(new DataColumn("Content", typeof(string)));
				reviews.Columns.Add(new DataColumn("Date", typeof(string)));

				foreach (Review review in item.CustomerReviews.Review)
				{
					DataRow row = reviews.NewRow();
					
					if (review.Summary != null)
						row["Summary"] = review.Summary;
					if (review.Content != null)
						row["Content"] = review.Content;
					if (review.Rating != null)
					{
						if (review.Rating.ToString().Trim().Length>1)
						{
							_imageURL = "images/stars/stars-" + review.Rating.ToString().Replace(".", "-") + ".gif";
						}
						else
						{
							_imageURL = "images/stars/stars-" + review.Rating.ToString() + "-0.gif";
						}
						row["Rating"] = _imageURL;
					}
					if (review.Date != null)
						row["Date"] = DateTime.Parse(review.Date).ToLongDateString();

					reviews.Rows.Add(row);
				}
				DataView dv = new DataView(reviews);

				reviewsDataGrid.DataSource = dv;
				reviewsDataGrid.DataBind();
			}

			if (item.MediumImage != null)
			{
				coverImage.ImageUrl = item.MediumImage.URL;
			}
			else
				coverImage.ImageUrl = "noimage.gif";

			if (item.Offers != null)
			{
				Offer[] offerArray = item.Offers.Offer;
				if (offerArray != null)
				{
					if (offerArray[0].OfferListing != null)
					{
						if (offerArray[0].OfferListing[0].Price != null)
						{
							lblSalesPrice.Text = offerArray[0].OfferListing[0].Price.FormattedPrice;
							if (lblSalesPrice.Text == "Too low to display")
							{
								lblSalesPrice.Text = "Price available at checkout";
							}
						}

						if (offerArray[0].OfferListing[0].Availability != null)
						{
							lblAvailibility.Text = offerArray[0].OfferListing[0].Availability;
						}
					}
				}
				else
				{
					string _amazonURL = item.DetailPageURL.ToString();
					imgbtnAddToCard.Enabled = false;
					imgbtnAddToCard.Visible = false;
					lblAvailibility.Text = "This item is not available through our store. Click <a href='" + _amazonURL + "'>here</a> to buy this item.";
				}
			}

			try
			{
				_listPrice = double.Parse(lblListPrice.Text.Replace("$", "").Trim());
				_salesPrice = double.Parse(lblSalesPrice.Text.Replace("$", "").Trim());
				_savings = ((_listPrice - _salesPrice) / (_listPrice) * 100);
				lblSavings.Text = _savings.ToString("##.##") + "%";
			}
			catch
			{
				lblSavings.Text = "N/A";
			}

			if (item.EditorialReviews != null)
			{
				if (item.EditorialReviews[0] != null)
				{
					if (item.EditorialReviews[0].Content != null)
					{
						descriptionLabel.Text = item.EditorialReviews[0].Content;
					}
				}
			}

			if (item.SimilarProducts != null)
			{
				DataTable products = new DataTable();
				products.Columns.Add(new DataColumn("ASIN", typeof(string)));
				products.Columns.Add(new DataColumn("Title", typeof(string)));

				foreach (SimilarProductsSimilarProduct product in item.SimilarProducts)
				{
					if (product != null)
					{
						DataRow row = products.NewRow();
						if (product.ASIN != null)
							row["ASIN"] = product.ASIN;
						if (product.Title != null)
							row["Title"] = product.Title;

						products.Rows.Add(row);
					}
				}
				DataView dv = new DataView(products);

				similarProductsDataGrid.DataSource = dv;
				similarProductsDataGrid.DataBind();
			}
		}
	}
	protected void imgbtnAddToCard_Click(object sender, ImageClickEventArgs e)
	{
		Response.Redirect("CheckOut.aspx?asin=" + asin);
	}
}
